@@ -2,8 +2,11 @@ use repl_framework::Repl;
 
 fn main() -> std::io::Result<()> {
     Repl::default()
+        // makes command with name "get" which calls Store::get when called
         .with_function("get", Store::get)
         .with_function("set", Store::set)
+        // commands with the name "" get called whenever the user inputs a commmand which is not declared
+        .with_function("", Store::unknown_command)
         .run()
 }
 
@@ -22,4 +25,7 @@ impl Store {
             self.data.insert(f[0].clone(), f[1].clone());
         })
     }
+    fn unknown_command(&mut self, args: Vec<String>) {
+        eprintln!("unknown command {:?}", args.first())
+    }
 }
